Module value

Module value 

Enums

Num
Represents the numeric primitive types that are supported for conversion.
Value
Represents primitive types that are supported for conversion into a BTreeMap that can support heterogeneous values. Inspired by serde_json::Values.